[dests] Fix hipTestClock, hipTestNew & hipTestGlobalVariable tests for nvcc
nvcc does not support global kernels in struct/class
Change-Id: I2d7297e0c3725564215e20dbdd31c0bb8d7a07de
[ROCm/hip commit: cca2c5afc8]
Tento commit je obsažen v:
@@ -33,8 +33,6 @@ THE SOFTWARE.
|
||||
#define LEN 512
|
||||
#define SIZE 2048
|
||||
|
||||
struct TestClock {
|
||||
|
||||
static __global__ void kernel1(int* Ad) {
|
||||
int tid = threadIdx.x + blockIdx.x * blockDim.x;
|
||||
Ad[tid] = clock() + clock64() + __clock() + __clock64();
|
||||
@@ -61,9 +59,8 @@ struct TestClock {
|
||||
assert(0 != A[i]);
|
||||
}
|
||||
}
|
||||
};
|
||||
|
||||
int main() {
|
||||
TestClock().run();
|
||||
run();
|
||||
passed();
|
||||
}
|
||||
|
||||
@@ -33,7 +33,6 @@ THE SOFTWARE.
|
||||
#define LEN 512
|
||||
#define SIZE 2048
|
||||
|
||||
struct TestPlacementNew {
|
||||
class A {
|
||||
public:
|
||||
__device__ A() {
|
||||
@@ -63,9 +62,8 @@ struct TestPlacementNew {
|
||||
assert(i == A[i]);
|
||||
}
|
||||
}
|
||||
};
|
||||
|
||||
int main() {
|
||||
TestPlacementNew().run();
|
||||
run();
|
||||
passed();
|
||||
}
|
||||
|
||||
Odkázat v novém úkolu
Zablokovat Uživatele